@@ -3,7 +3,7 @@
 # If you want to add an OS to extend AWStats database detection capabilities,
 # you must add an entry in OSSearchIDOrder, in OSHashID and in OSHashLib.
 #-------------------------------------------------------
-# $Revision: 1.29 $ - $Author: eldy $ - $Date: 2009/12/09 11:06:54 $
+# $Revision: 1.32 $ - $Author: eldy $ - $Date: 2012/08/10 19:24:29 $
 
 # 2005-08-19 Sean Carlos http://www.antezeta.com/awstats.html
 #              - added specific Linux distributions in addition to 
@@ -13,6 +13,13 @@
 
 #package AWSOS;
 
+# Relocated from main file for easier editing
+%OSFamily = (
+	'win'   => 'Windows',
+	'mac'   => 'Macintosh',
+	'linux' => 'Linux',
+	'bsd'   => 'BSD'
+);
 
 # OSSearchIDOrder
 # This list is used to know in which order to search Operating System IDs
@@ -35,6 +42,12 @@
 'win(.*)16','windows[_+ ]3',					# This works for windows_31 and windows_3.1
 'win(.*)ce',
 # Macintosh OS family
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]9',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]8',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]7',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]6',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]5',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]4',
 'mac[_+ ]os[_+ ]x',
 'mac[_+ ]?p',									# This works for macppc and mac_ppc and mac_powerpc
 'mac[_+ ]68',									# This works for mac_6800 and mac_68k
@@ -136,6 +149,12 @@
 'msie[_+ ]','winunknown',
 'ms[_+ ]frontpage','winunknown',
 # Macintosh OS family
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]9','macosx9',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]8','macosx8',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]7','macosx7',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]6','macosx6',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]5','macosx5',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]4','macosx4',
 'mac[_+ ]os[_+ ]x','macosx', 'vienna', 'macosx', 'newsfire', 'macosx', 'applesyndication', 'macosx',
 'mac[_+ ]?p','macintosh','mac[_+ ]68','macintosh','macweb','macintosh','macintosh','macintosh',
 # Linux family (linuxyyy)
@@ -193,7 +212,7 @@
 'cp/m','cp/m',
 'crayos','crayos',
 'dreamcast','dreamcast',
-'iphone[_+ ]os','iphone',
+'iphone[_+ ]os','ios',
 'risc[_+ ]?os','riscos',
 'symbian','symbian',
 'webtv','webtv',
@@ -224,7 +243,13 @@
 'winunknown','Windows (unknown version)',
 'winxbox','<a href="http://www.xbox.com/" title="Microsoft XBOX home page [new window]" target="_blank">Microsoft XBOX</a>',
 # Macintosh OS
-'macosx','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X</a>',
+'macosx9','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X 10.9</a>',
+'macosx8','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X 10.8 Mountain Lion</a>',
+'macosx7','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X 10.7 Lion</a>',
+'macosx6','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X 10.6 Snow Leopard</a>',
+'macosx5','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X 10.5 Leopard</a>',
+'macosx4','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X 10.4 Tiger</a>',
+'macosx','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank">Mac OS X others</a>',
 'macintosh','<a href="http://www.apple.com/" title="Mac OS home page [new window]" target="_blank">Mac OS</a>',
 # Linux
 'linuxandroid','<a href="http://code.google.com/android/" title="Google Android home page [new window]" target="_blank">Google Android</a>',
@@ -246,7 +271,7 @@
 'linux','<a href="http://www.distrowatch.com/" title="Linux DistroWatch home page. Useful if you find the associated user agent string in your logs. [new window]" target="_blank">Linux (Unknown/unspecified)</a>',
 'linux','GNU Linux (Unknown or unspecified distribution)',
 # Hurd
-'gnu','<a href="www.gnu.org/software/hurd/hurd.html" title="GNU Hurd home page [new window]" target="_blank">GNU Hurd</a>',
+'gnu','<a href="http://www.gnu.org/software/hurd/hurd.html" title="GNU Hurd home page [new window]" target="_blank">GNU Hurd</a>',
 # BSDs
 'bsdi','<a href="http://en.wikipedia.org/wiki/BSDi" title="BSDi home page [new window]" target="_blank">BSDi</a>',
 'bsdkfreebsd','<a href="http://www.debian.org/ports/kfreebsd-gnu/" title="Debian GNU/kFreeBSD" target="_blank">GNU/kFreeBSD</a>',
@@ -282,7 +307,7 @@
 'cp/m','<a href="http://www.digitalresearch.biz/CPM.HTM" title="CP/M home page [new window]" target="_blank">CP/M</a>',
 'crayos','<a href="http://www.cray.com/" title="CrayOS home page [new window]" target="_blank">CrayOS</a>',
 'dreamcast','<a href="http://www.sega.com/" title="Dreamcast home page [new window]" target="_blank">Dreamcast</a>',
-'iphone','<a href="http://www.apple.com/iphone/" title="iPhone home page [new window]" target="_blank">iPhone OS (iPhone/iPod)</a>',
+'ios','<a href="http://www.apple.com/" title="Apple home page [new window]" target="_blank">iOS (iPhone/iPod/iPad/...)</a>',
 'riscos','<a href="http://www.riscos.com/" title="RISC OS home page [new window]" target="_blank">RISC OS</a>',
 'symbian','<a href="http://www.symbian.com/" title="Symbian OS home page [new window]" target="_blank">Symbian OS</a>',
 'webtv','<a href="http://www.webtv.com/" title="WebTV home page [new window]" target="_blank">WebTV</a>',
